""" Addon Information """
# ------------
# EventScripts Script-Addon:    BackRaw's AWP-Restrict (BAR, bar.py, 6.1kb)
# Author:                       BackRaw - http://forums.eventscripts.com/profile.php?mode=viewprofile&u=13683
#                                         http://addons.eventscripts.com/addons/user/13683
# Version:                      1.0
# ------------

""" Imports """
# ------------
# EventScripts Core-Module                - ES-functionality
import es
# Config Object                           - Configuration File: ./addons/eventscripts/bar/bar_config.ini
from configobj import ConfigObj
# ------------

""" Global Variables """
# ------------
# This variable will hold the Prefix of BAR.
# We'll need the same string often, a global variable is the best for that.
prefix = "#green[#lightgreenBackRaw's AWP-Restrict#green] #default"
# ------------

""" Configuration File wrapper """
def config(name, section=False):
    f = ConfigObj(es.getAddonPath('bar') + '/bar_config.ini')
    if section:
        return int(f[section][name])
    return int(f[name])

""" Class - AWP """
# ------------
# This class holds allowed and counted AWPs for CT and T.
# If a player picks up an AWP, it drops the player's AWP when the allowed AWP-count is already reached.
# It also contains buy-restriction, console-buy, too.
# ------------
class AWP(object):
    def __init__(self):
        self.count_t = self.count_ct = 0
        self.allowed_t = self.allowed_ct = 0
        self.rcount = 0
    def roundStart(self):
        count = es.getplayercount()
        if count <= 5:
            count = config('5', 'restriction').getInt()
        elif count > 5 and count < 15:
            count = config('15', 'restriction').getInt()
        elif count > 15 and count < 25:
            count = config('25', 'restriction').getInt()
        elif count > 25 and count < 35:
            count = config('35', 'restriction').getInt()
        elif count > 35 and count < 45:
            count = config('45', 'restriction').getInt()
        elif count > 45 and count < 55:
            count = config('55', 'restriction').getInt()
        elif count >= 55:
            count = config('more', 'restriction').getInt()
        self.allowed_ct = self.allowed_t = count
        self.count_ct = self.count_t = 0
        if config('announce'):
            self.rcount += 1
            if self.rcount in [1, 3]:
                es.msg('#multi', '%sYou can use #lightgreen%s #greenAWP%s #defaultper team.' % (prefix, count, 's' if count > 1 else ''))
                self.rcount = 0
    def dontAllow(self, userid, index):
        team = es.getplayerteam(userid)
        es.server.cmd('es_xremove %s' % index)
        if config('pickup'):
            es.tell(userid, '#multi', '%sYou cannot pickup this #greenAWP #lightgreen- %s/%s #defaultAWPs in use.' % (prefix, self.count_t if team == 2 else self.count_ct, self.allowed_t if team == 2 else self.allowed_ct))
        es.sexec(userid, 'use slot2')
    def awpPickup(self, userid, index):
        team = es.getplayerteam(userid)
        if team == 2:
            if self.count_t >= self.allowed_t:
                self.dontAllow(userid, index)
            else:
                self.count_t += 1
        elif team == 3:
            if self.count_ct >= self.allowed_ct:
                self.dontAllow(userid, index)
            else:
                self.count_ct += 1
    def awpBuy(self, team):
        allow = 1
        if team == 2 and self.count_t >= self.allowed_t or team == 3 and self.count_ct >= self.allowed_ct:
            allow = 0
        return allow
    def awpDrop(self, team):
        if team == 2 and self.count_t:
            self.count_t -= 1
        elif team == 3 and self.count_t:
            self.count_ct -= 1
awp = AWP()

""" Events """
# ------------
# On round_start, re-allow AWP-counts.
# ------------
def round_start(ev):
    awp.roundStart()

# ------------
# On item_pickup - if the item is AWP - remove the AWP or let the player pick it up.
# ------------
def item_pickup(ev):
    if ev['item'] == 'awp':
        index = 0
        userid = ev['userid']
        handle = es.getplayerhandle(userid)
        for x in es.createentitylist('weapon_awp'):
            if es.getindexprop(x, 'CBaseEntity.m_hOwnerEntity') == handle:
                index = x
        awp.awpPickup(userid, index)

# ------------
# On player_death, count the AWP-count for the team down, if the player had an AWP.
# ------------
def player_death(ev):
    _awp = 0
    for x in es.createentitylist('weapon_awp'):
        if es.getindexprop(x, 'CBaseEntity.m_hOwnerEntity') == -1:
            _awp = 1
    if _awp:
        awp.awpDrop(int(ev['es_userteam']))

""" Client Command Filter """
# ------------
# This checks buy and drop-commands, and calls the functions in the AWP-class.
# ------------
def clientFilter(userid, args):
    cmd = args[0].lower()
    if cmd in ['buy', 'drop']:
        team = es.getplayerteam(userid)
        weapon = es.createplayerlist(userid)[int(userid)]['weapon'].replace('weapon_', '')
        if cmd == 'buy':
            buy = args[1].lower()
            if 'awp' in buy and not awp.awpBuy(team):
                if config('buy'):
                    es.tell(userid, '#multi', '%sYou cannot buy this #greenAWP #lightgreen- %s/%s #defaultAWPs in use.' % (prefix, awp.count_t if team == 2 else awp.count_ct, awp.allowed_t if team == 2 else awp.allowed_ct))
                return False
            elif 'awp' not in buy and weapon == 'awp':
                awp.awpDrop(team)
        elif cmd == 'drop' and weapon == 'awp':
            awp.awpDrop(team)
    return True

""" EventScripts Main-Control functions """
# ------------
# On load, register a Client Console-Command Filter and re-allow AWP-counts.
# ------------
def load():
    es.ServerVar('bar_ver', '1.0').makepublic()
    es.addons.registerClientCommandFilter(clientFilter)
    awp.roundStart()

# ------------
# On unload, un-register the Client Console-Command Filter.
# ------------
def unload():
    es.addons.unregisterClientCommandFilter(clientFilter)

""" End Code """
